spannertools.DuratedComplexBeam
===============================

.. abjad-lineage:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam

.. autoclass:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.components
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.direction
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.durations
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.isolated_nib_direction
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.nibs_towards_nonbeamable_components
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.span_beam_count
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__contains__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__copy__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__eq__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__format__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__getitem__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__hash__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__len__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__lt__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__ne__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__repr__

Bases
-----

- :py:class:`spannertools.ComplexBeam <abjad.tools.spannertools.ComplexBeam.ComplexBeam>`

- :py:class:`spannertools.Beam <abjad.tools.spannertools.Beam.Beam>`

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.direction
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.durations
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.isolated_nib_direction
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.nibs_towards_nonbeamable_components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.span_beam_count
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__hash__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__repr__
   :noindex:
